@@ -20,10 +20,10 @@
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include <KLocalizedString>
-
 #include "configdialog.h"
 
+#include <KLocalizedString>
+
 #include "massif-visualizer-settings.h"
 #include "ui_config.h"
 
@@ -38,7 +38,7 @@ ConfigDialog::ConfigDialog(QWidget* parent)
     QWidget* settingsPage = new QWidget(this);
     m_ui->setupUi(settingsPage);
 
-    addPage(settingsPage, Settings::self(), i18n("Settings"));
+    addPage(settingsPage, Settings::self(), i18nc("@title:tab", "Settings"));
     setFaceType(KPageDialog::Plain);
 }
 
@@ -50,3 +50,5 @@ bool ConfigDialog::isShown()
 {
     return KConfigDialog::showDialog(QStringLiteral("settings"));
 }
+
+#include "moc_configdialog.cpp"
