@@ -26,7 +26,9 @@
 #include "parserprivate.h"
 #include "snapshotitem.h"
 
-#include <QtCore/QIODevice>
+#include <QIODevice>
+
+#include <memory>
 
 using namespace Massif;
 
@@ -44,14 +46,14 @@ FileData* Parser::parse(QIODevice* file, const QStringList& customAllocators, QA
     Q_ASSERT(file->isOpen());
     Q_ASSERT(file->isReadable());
 
-    QScopedPointer<FileData> data(new FileData);
+    std::unique_ptr<FileData> data(new FileData);
 
-    ParserPrivate p(this, file, data.data(), customAllocators, shouldStop);
+    ParserPrivate p(this, file, data.get(), customAllocators, shouldStop);
 
     if (p.error()) {
         m_errorLine = p.errorLine();
         m_errorLineString = p.errorLineString();
-        return 0;
+        return nullptr;
     } else {
         m_errorLine = -1;
         m_errorLineString.clear();
@@ -80,7 +82,7 @@ FileData* Parser::parse(QIODevice* file, const QStringList& customAllocators, QA
     }
     // peak might still be zero if we have no snapshots, should be handled in the UI then
 
-    return data.take();
+    return data.release();
 }
 
 int Parser::errorLine() const
@@ -97,3 +99,5 @@ void Parser::setProgress(int value)
 {
     emit progress(value);
 }
+
+#include "moc_parser.cpp"
